lexbor_erl_app (lexbor_erl v0.3.0)

OTP application behavior for lexbor_erl.

Starts the supervisor tree with a configured pool size. The pool size defaults to the number of scheduler threads if not configured.

Configuration example:

  {lexbor_erl, [
    {pool_size, 8},           % Number of workers (default: schedulers_online)
    {op_timeout_ms, 3000}     % Operation timeout (default: 3000ms)
  ]}

Summary

Functions

Start the application and supervisor tree.

Stop the application.

Functions

start(Type, Args)

Start the application and supervisor tree.

Reads the pool_size configuration or uses the number of scheduler threads as the default.

stop(State)

Stop the application.